=== modified file 'drizzled/enum.h'
--- drizzled/enum.h	2010-03-25 20:50:51 +0000
+++ drizzled/enum.h	2010-04-20 18:23:07 +0000
@@ -1055,7 +1055,8 @@
   ER_SCHEMA_DOES_NOT_EXIST,
   ER_ALTER_SCHEMA,
   ER_DROP_SCHEMA,
-  ER_ERROR_LAST= ER_CORRUPT_TABLE_DEFINITION
+  ER_USE_SQL_BIG_RESULT,
+  ER_ERROR_LAST= ER_USE_SQL_BIG_RESULT
 };
 
 enum drizzle_exit_codes {

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2010-04-16 05:36:53 +0000
+++ drizzled/error.cc	2010-04-20 18:23:07 +0000
@@ -909,6 +909,7 @@
   add(ER_SCHEMA_DOES_NOT_EXIST, N_("Schema does not exist: %s"));
   add(ER_ALTER_SCHEMA, N_("Error altering schema: %s"));
   add(ER_DROP_SCHEMA, +N_("Error droppping Schema : %s"));
+  add(ER_USE_SQL_BIG_RESULT, N_("Temporary table too large, rerun with SQL_BIG_RESULT."));
 
 
   add(EE_CANTUNLOCK, N_("Can't unlock file (Errcode: %d)"));

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2010-02-27 23:47:33 +0000
+++ drizzled/join.cc	2010-04-20 18:23:07 +0000
@@ -2348,7 +2348,7 @@
   {
     /* Get reference pointers to sum functions in place */
     memcpy(ref_pointer_array, rollup.ref_pointer_arrays[i],
-     ref_pointer_array_size);
+           ref_pointer_array_size);
     if ((!having || having->val_int()))
     {
       int write_error;
@@ -2362,11 +2362,8 @@
       copy_sum_funcs(sum_funcs_end[i+1], sum_funcs_end[i]);
       if ((write_error= table_arg->cursor->ha_write_row(table_arg->record[0])))
       {
-  if (create_myisam_from_heap(session, table_arg,
-                                    tmp_table_param.start_recinfo,
-                                    &tmp_table_param.recinfo,
-                                    write_error, 0))
-    return 1;
+        my_error(ER_USE_SQL_BIG_RESULT, MYF(0));
+        return 1;
       }
     }
   }
@@ -2821,12 +2818,9 @@
       {
         if (!table->cursor->is_fatal_error(error, HA_CHECK_DUP))
           goto end;
-        if (create_myisam_from_heap(join->session, table,
-                                          join->tmp_table_param.start_recinfo,
-                                          &join->tmp_table_param.recinfo,
-                  error, 1))
-          return NESTED_LOOP_ERROR;        // Not a table_is_full error
-        table->s->uniques= 0;			// To ensure rows are the same
+
+        my_error(ER_USE_SQL_BIG_RESULT, MYF(0));
+        return NESTED_LOOP_ERROR;        // Table is_full error
       }
       if (++join->send_records >= join->tmp_table_param.end_write_records && join->do_send_rows)
       {
@@ -2901,14 +2895,8 @@
   copy_funcs(join->tmp_table_param.items_to_copy);
   if ((error=table->cursor->ha_write_row(table->record[0])))
   {
-    if (create_myisam_from_heap(join->session, table,
-                                join->tmp_table_param.start_recinfo,
-                                &join->tmp_table_param.recinfo,
-				error, 0))
-      return NESTED_LOOP_ERROR;            // Not a table_is_full error
-    /* Change method to update rows */
-    table->cursor->ha_index_init(0, 0);
-    join->join_tab[join->tables-1].next_select= end_unique_update;
+    my_error(ER_USE_SQL_BIG_RESULT, MYF(0));
+    return NESTED_LOOP_ERROR;        // Table is_full error
   }
   join->send_records++;
   return NESTED_LOOP_OK;

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2010-02-23 22:38:08 +0000
+++ drizzled/sql_select.cc	2010-04-20 18:23:07 +0000
@@ -119,8 +119,10 @@
 
   if (select_lex->master_unit()->is_union() ||
       select_lex->master_unit()->fake_select_lex)
+  {
     res= drizzle_union(session, lex, result, &lex->unit,
 		       setup_tables_done_option);
+  }
   else
   {
     Select_Lex_Unit *unit= &lex->unit;
@@ -3231,11 +3233,11 @@
     }
     else if (join->sort_and_group && !tmp_tbl->precomputed_group_by)
     {
-      end_select=end_write_group;
+      end_select= end_write_group;
     }
     else
     {
-      end_select=end_write;
+      end_select= end_write;
       if (tmp_tbl->precomputed_group_by)
       {
         /*
@@ -4217,11 +4219,12 @@
         if (!join->having || join->having->val_int())
         {
           int error= table->cursor->ha_write_row(table->record[0]);
-          if (error && create_myisam_from_heap(join->session, table,
-                                              join->tmp_table_param.start_recinfo,
-                                                &join->tmp_table_param.recinfo,
-                                              error, 0))
-          return NESTED_LOOP_ERROR;
+
+          if (error)
+          {
+            my_error(ER_USE_SQL_BIG_RESULT, MYF(0));
+            return NESTED_LOOP_ERROR;
+          }
         }
         if (join->rollup.state != ROLLUP::STATE_NONE)
         {

=== modified file 'drizzled/sql_union.cc'
--- drizzled/sql_union.cc	2010-02-05 04:05:31 +0000
+++ drizzled/sql_union.cc	2010-04-20 18:23:07 +0000
@@ -66,10 +66,11 @@
   if ((error= table->cursor->ha_write_row(table->record[0])))
   {
     /* create_myisam_from_heap will generate error if needed */
-    if (table->cursor->is_fatal_error(error, HA_CHECK_DUP) &&
-        create_myisam_from_heap(session, table, tmp_table_param.start_recinfo,
-                                &tmp_table_param.recinfo, error, 1))
-      return 1;
+    if (table->cursor->is_fatal_error(error, HA_CHECK_DUP))
+    {
+      my_error(ER_USE_SQL_BIG_RESULT, MYF(0));
+      return true;
+    }
   }
   return 0;
 }

=== modified file 'drizzled/statement/insert_select.cc'
--- drizzled/statement/insert_select.cc	2010-02-11 20:01:37 +0000
+++ drizzled/statement/insert_select.cc	2010-04-20 18:23:07 +0000
@@ -75,6 +75,7 @@
                          session->lex, 
                          sel_result, 
                          OPTION_SETUP_TABLES_DONE);
+
       /*
          Invalidate the table in the query cache if something changed
          after unlocking when changes become visible.

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2010-04-19 19:23:14 +0000
+++ drizzled/table.cc	2010-04-20 18:23:07 +0000
@@ -2345,7 +2345,9 @@
   if (group)
   {
     if (! param->quick_group)
+    {
       group= 0;					// Can't use group key
+    }
     else for (order_st *tmp=group ; tmp ; tmp=tmp->next)
     {
       /*
@@ -2589,7 +2591,9 @@
 
   /* If result table is small; use a heap */
   /* future: storage engine selection can be made dynamic? */
-  if (blob_count || using_unique_constraint ||
+  if (blob_count || using_unique_constraint || 
+      (session->lex->select_lex.options & SELECT_BIG_RESULT) ||
+      (session->lex->current_select->olap == ROLLUP_TYPE) ||
       (select_options & (OPTION_BIG_TABLES | SELECT_SMALL_RESULT)) == OPTION_BIG_TABLES)
   {
     share->storage_engine= myisam_engine;
@@ -2597,7 +2601,9 @@
     if (group &&
 	(param->group_parts > table->cursor->getEngine()->max_key_parts() ||
 	 param->group_length > table->cursor->getEngine()->max_key_length()))
+    {
       using_unique_constraint= true;
+    }
   }
   else
   {
@@ -3262,117 +3268,6 @@
   session->set_proc_info(save_proc_info);
 }
 
-/**
-  If a HEAP table gets full, create a MyISAM table and copy all rows
-  to this.
-*/
-
-bool create_myisam_from_heap(Session *session, Table *table,
-                             MI_COLUMNDEF *start_recinfo,
-                             MI_COLUMNDEF **recinfo,
-			     int error, bool ignore_last_dupp_key_error)
-{
-  Table new_table;
-  TableShare share;
-  const char *save_proc_info;
-  int write_err;
-
-  if (table->s->db_type() != heap_engine ||
-      error != HA_ERR_RECORD_FILE_FULL)
-  {
-    table->print_error(error, MYF(0));
-    return true;
-  }
-
-  // Release latches since this can take a long time
-  plugin::TransactionalStorageEngine::releaseTemporaryLatches(session);
-
-  new_table= *table;
-  share= *table->s;
-  new_table.s= &share;
-  new_table.s->storage_engine= myisam_engine;
-  if (not (new_table.cursor= new_table.s->db_type()->getCursor(share, &new_table.mem_root)))
-    return true;				// End of memory
-
-  save_proc_info=session->get_proc_info();
-  session->set_proc_info("converting HEAP to MyISAM");
-
-  if (new_table.create_myisam_tmp_table(table->key_info, start_recinfo,
-					recinfo, session->lex->select_lex.options |
-					session->options))
-    goto err2;
-  if (new_table.open_tmp_table())
-    goto err1;
-  if (table->cursor->indexes_are_disabled())
-    new_table.cursor->ha_disable_indexes(HA_KEY_SWITCH_ALL);
-  table->cursor->ha_index_or_rnd_end();
-  table->cursor->ha_rnd_init(1);
-  if (table->no_rows)
-  {
-    new_table.cursor->extra(HA_EXTRA_NO_ROWS);
-    new_table.no_rows=1;
-  }
-
-  /* HA_EXTRA_WRITE_CACHE can stay until close, no need to disable it */
-  new_table.cursor->extra(HA_EXTRA_WRITE_CACHE);
-
-  /*
-    copy all old rows from heap table to MyISAM table
-    This is the only code that uses record[1] to read/write but this
-    is safe as this is a temporary MyISAM table without timestamp/autoincrement.
-  */
-  while (!table->cursor->rnd_next(new_table.record[1]))
-  {
-    write_err= new_table.cursor->ha_write_row(new_table.record[1]);
-    if (write_err)
-      goto err;
-  }
-  /* copy row that filled HEAP table */
-  if ((write_err=new_table.cursor->ha_write_row(table->record[0])))
-  {
-    if (new_table.cursor->is_fatal_error(write_err, HA_CHECK_DUP) ||
-	!ignore_last_dupp_key_error)
-      goto err;
-  }
-
-  /* remove heap table and change to use myisam table */
-  (void) table->cursor->ha_rnd_end();
-  (void) table->cursor->close();                  // This deletes the table !
-  delete table->cursor;
-  table->cursor= NULL;
-  new_table.s= table->s;                       // Keep old share
-  *table= new_table;
-  *table->s= share;
-
-  table->cursor->change_table_ptr(table, table->s);
-  table->use_all_columns();
-  if (save_proc_info)
-  {
-    const char *new_proc_info=
-      (!strcmp(save_proc_info,"Copying to tmp table") ?
-      "Copying to tmp table on disk" : save_proc_info);
-    session->set_proc_info(new_proc_info);
-  }
-  return false;
-
- err:
-  table->print_error(write_err, MYF(0));
-  (void) table->cursor->ha_rnd_end();
-  (void) new_table.cursor->close();
-
- err1:
-  {
-    TableIdentifier identifier(new_table.s->getSchemaName(), new_table.s->table_name.str, new_table.s->table_name.str);
-    new_table.s->db_type()->doDropTable(*session, identifier);
-  }
-
- err2:
-  delete new_table.cursor;
-  session->set_proc_info(save_proc_info);
-  table->mem_root= new_table.mem_root;
-  return true;
-}
-
 my_bitmap_map *Table::use_all_columns(MyBitmap *bitmap)
 {
   my_bitmap_map *old= bitmap->getBitmap();

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2010-04-09 11:55:54 +0000
+++ drizzled/table.h	2010-04-20 18:23:07 +0000
@@ -54,11 +54,6 @@
 typedef enum enum_table_category TABLE_CATEGORY;
 typedef struct st_columndef MI_COLUMNDEF;
 
-bool create_myisam_from_heap(Session *session, Table *table,
-                             MI_COLUMNDEF *start_recinfo,
-                             MI_COLUMNDEF **recinfo,
-                             int error, bool ignore_last_dupp_key_error);
-
 /**
  * Class representing a set of records, either in a temporary, 
  * normal, or derived table.

=== modified file 'tests/r/insert.result'
--- tests/r/insert.result	2009-05-15 07:55:30 +0000
+++ tests/r/insert.result	2010-04-20 18:23:07 +0000
@@ -77,6 +77,8 @@
 count(*)
 500
 insert into  t2 select t1.* from t1, t2 t, t3 where  t1.id1 = t.id2 and t.id2 = t3.id3;
+ERROR HY000: Temporary table too large, rerun with SQL_BIG_RESULT.
+insert into  t2 select SQL_BIG_RESULT t1.* from t1, t2 t, t3 where  t1.id1 = t.id2 and t.id2 = t3.id3;
 select count(*) from t2;
 count(*)
 25500

=== modified file 'tests/r/rr_from_cache.result'
--- tests/r/rr_from_cache.result	2009-03-12 17:27:35 +0000
+++ tests/r/rr_from_cache.result	2010-04-20 18:23:07 +0000
@@ -1,23 +1,23 @@
 create table t1 (a int, b int, x varchar(1024) default 'x');
 insert t1 values (rand()*1e9, rand()*1e9, 'x');
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
 SELECT CASE WHEN a >0 THEN 'true' ELSE 'false' END from t1 order by a limit 1;
 CASE WHEN a >0 THEN 'true' ELSE 'false' END 
 true

=== modified file 'tests/r/small_tmp_table.result'
--- tests/r/small_tmp_table.result	2009-01-30 20:58:56 +0000
+++ tests/r/small_tmp_table.result	2010-04-20 18:23:07 +0000
@@ -11,6 +11,8 @@
 ('AAAAAAAAAJ','AAAAAAAAAJ'), ('AAAAAAAAAK','AAAAAAAAAK');
 set tmp_table_size=1024;
 SELECT MAX(a) FROM t1 GROUP BY a,b;
+ERROR HY000: Temporary table too large, rerun with SQL_BIG_RESULT.
+SELECT SQL_BIG_RESULT MAX(a) FROM t1 GROUP BY a,b;
 MAX(a)
 AAAAAAAAAA
 AAAAAAAAAB

=== modified file 'tests/r/sum_distinct.result'
--- tests/r/sum_distinct.result	2008-12-06 22:41:03 +0000
+++ tests/r/sum_distinct.result	2010-04-20 18:23:07 +0000
@@ -51,6 +51,7 @@
 s1	s2	s3
 42	0	7
 SELECT
+SQL_BIG_RESULT
 SUM(DISTINCT LENGTH(g1.name)) s1,
 SUM(DISTINCT SUBSTRING(g2.name, 1, 3)) s2,
 SUM(DISTINCT LENGTH(SUBSTRING(g3.name, 1, 4))) s3
@@ -70,7 +71,7 @@
 FROM t1;
 s1	s2	s3
 42	0	7
-SELECT SQL_BUFFER_RESULT
+SELECT SQL_BIG_RESULT
 SUM(DISTINCT LENGTH(g1.name)) s1,
 SUM(DISTINCT SUBSTRING(g2.name, 1, 3)) s2,
 SUM(DISTINCT LENGTH(SUBSTRING(g3.name, 1, 4))) s3

=== modified file 'tests/r/union.result'
--- tests/r/union.result	2010-03-22 19:44:37 +0000
+++ tests/r/union.result	2010-04-20 18:23:07 +0000
@@ -783,7 +783,7 @@
 insert into t1 select * from t2;
 insert into t2 select * from t1;
 set local tmp_table_size=1024;
-select count(*) from (select * from t1 union all select * from t2 order by 1) b;
+select SQL_BIG_RESULT count(*) from (select SQL_BIG_RESULT * from t1 union all select * from t2 order by 1) b;
 count(*)
 21
 select count(*) from t1;

=== modified file 'tests/r/variables.result'
--- tests/r/variables.result	2010-03-18 01:23:59 +0000
+++ tests/r/variables.result	2010-04-20 18:23:07 +0000
@@ -7,6 +7,7 @@
 set @my_server_id                 =@@global.server_id;
 set @my_storage_engine            =@@global.storage_engine;
 set @my_myisam_sort_buffer_size	  =@@global.myisam_sort_buffer_size;
+set @my_tx_isolation	  =@@global.tx_isolation;
 set @`test`=1;
 select @test, @`test`, @TEST, @`TEST`, @"teSt";
 @test	@`test`	@TEST	@`TEST`	@"teSt"
@@ -585,6 +586,46 @@
 set global thread_cache_size         =@my_thread_cache_size;
 ERROR HY000: Unknown system variable 'thread_cache_size'
 set global myisam_sort_buffer_size   =@my_myisam_sort_buffer_size;
+SHOW GLOBAL VARIABLES LIKE 'max_join_size';
+Variable_name	Value
+max_join_size	2147483647
+SHOW LOCAL VARIABLES LIKE 'max_join_size';
+Variable_name	Value
+max_join_size	100
+set GLOBAL bulk_insert_buffer_size=DEFAULT;
+set GLOBAL join_buffer_size=DEFAULT;
+set GLOBAL max_allowed_packet=DEFAULT;
+set GLOBAL max_connect_errors=DEFAULT;
+set GLOBAL max_heap_table_size=DEFAULT;
+set GLOBAL max_join_size=DEFAULT;
+set GLOBAL max_sort_length=DEFAULT;
+set GLOBAL max_write_lock_count=DEFAULT;
+set GLOBAL myisam_sort_buffer_size=DEFAULT;
+set GLOBAL mysql_protocol_buffer_length=DEFAULT;
+set GLOBAL read_buffer_size=DEFAULT;
+set GLOBAL read_rnd_buffer_size=DEFAULT;
+set GLOBAL server_id=DEFAULT;
+set GLOBAL sort_buffer_size=DEFAULT;
+set GLOBAL table_open_cache=DEFAULT;
+set GLOBAL storage_engine= @my_storage_engine;
+set GLOBAL tmp_table_size=DEFAULT;
+set GLOBAL tx_isolation= @my_tx_isolation;
+set SESSION bulk_insert_buffer_size=DEFAULT;
+set SESSION join_buffer_size=DEFAULT;
+set SESSION max_allowed_packet=DEFAULT;
+set SESSION max_heap_table_size=DEFAULT;
+set SESSION max_join_size=DEFAULT;
+set SESSION max_sort_length=DEFAULT;
+set SESSION read_buffer_size=DEFAULT;
+set SESSION read_rnd_buffer_size=DEFAULT;
+set SESSION sort_buffer_size=DEFAULT;
+set SESSION sql_big_selects=DEFAULT;
+set SESSION sql_buffer_result=DEFAULT;
+set SESSION sql_select_limit=DEFAULT;
+set SESSION sql_warnings=DEFAULT;
+set SESSION storage_engine= @my_storage_engine;
+set SESSION tmp_table_size=DEFAULT;
+set SESSION tx_isolation= @my_tx_isolation;
 show global variables where variable_name='table_definition_cache' or Variable_name='table_lock_wait_timeout';
 Variable_name	Value
 table_definition_cache	#

=== modified file 'tests/t/insert.test'
--- tests/t/insert.test	2009-05-15 07:55:30 +0000
+++ tests/t/insert.test	2010-04-20 18:23:07 +0000
@@ -116,7 +116,9 @@
  }
 enable_query_log;
 select count(*) from t2;
+--error 1697
 insert into  t2 select t1.* from t1, t2 t, t3 where  t1.id1 = t.id2 and t.id2 = t3.id3;
+insert into  t2 select SQL_BIG_RESULT t1.* from t1, t2 t, t3 where  t1.id1 = t.id2 and t.id2 = t3.id3;
 select count(*) from t2;
 drop table t1,t2,t3;
 

=== modified file 'tests/t/rr_from_cache.test'
--- tests/t/rr_from_cache.test	2009-03-12 17:27:35 +0000
+++ tests/t/rr_from_cache.test	2010-04-20 18:23:07 +0000
@@ -1,23 +1,23 @@
 # Test case from email from  Sergei Golubchik for testing usage of rr cache
 create table t1 (a int, b int, x varchar(1024) default 'x');
 insert t1 values (rand()*1e9, rand()*1e9, 'x');
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
-insert t1 select rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
+insert t1 select SQL_BIG_RESULT rand()*1e9, rand()*1e9,'x' from t1;
 SELECT CASE WHEN a >0 THEN 'true' ELSE 'false' END from t1 order by a limit 1;
 drop table t1;

=== modified file 'tests/t/small_tmp_table.test'
--- tests/t/small_tmp_table.test	2009-01-30 20:58:56 +0000
+++ tests/t/small_tmp_table.test	2010-04-20 18:23:07 +0000
@@ -19,8 +19,11 @@
 
 set tmp_table_size=1024;
 
+--error 1697
+SELECT MAX(a) FROM t1 GROUP BY a,b;
+
 --replace_regex /in table '[^']+'/in table 'tmp_table'/
-SELECT MAX(a) FROM t1 GROUP BY a,b;
+SELECT SQL_BIG_RESULT MAX(a) FROM t1 GROUP BY a,b;
 
 set tmp_table_size=default;
 

=== modified file 'tests/t/sum_distinct.test'
--- tests/t/sum_distinct.test	2008-12-06 22:41:03 +0000
+++ tests/t/sum_distinct.test	2010-04-20 18:23:07 +0000
@@ -59,6 +59,7 @@
 FROM t1 g1, t1 g2, t1 g3;
 
 SELECT
+  SQL_BIG_RESULT
   SUM(DISTINCT LENGTH(g1.name)) s1,
   SUM(DISTINCT SUBSTRING(g2.name, 1, 3)) s2,
   SUM(DISTINCT LENGTH(SUBSTRING(g3.name, 1, 4))) s3
@@ -73,7 +74,7 @@
   SUM(DISTINCT LENGTH(SUBSTRING(name, 1, 4))) s3
 FROM t1;
 
-SELECT SQL_BUFFER_RESULT
+SELECT SQL_BIG_RESULT
   SUM(DISTINCT LENGTH(g1.name)) s1,
   SUM(DISTINCT SUBSTRING(g2.name, 1, 3)) s2,
   SUM(DISTINCT LENGTH(SUBSTRING(g3.name, 1, 4))) s3

=== modified file 'tests/t/union.test'
--- tests/t/union.test	2010-02-15 18:29:31 +0000
+++ tests/t/union.test	2010-04-20 18:23:07 +0000
@@ -457,7 +457,7 @@
 insert into t1 select * from t2;
 insert into t2 select * from t1;
 set local tmp_table_size=1024;
-select count(*) from (select * from t1 union all select * from t2 order by 1) b;
+select SQL_BIG_RESULT count(*) from (select SQL_BIG_RESULT * from t1 union all select * from t2 order by 1) b;
 select count(*) from t1;
 select count(*) from t2;
 drop table t1,t2;

=== modified file 'tests/t/variables.test'
--- tests/t/variables.test	2010-03-18 01:23:59 +0000
+++ tests/t/variables.test	2010-04-20 18:23:07 +0000
@@ -16,6 +16,7 @@
 set @my_server_id                 =@@global.server_id;
 set @my_storage_engine            =@@global.storage_engine;
 set @my_myisam_sort_buffer_size	  =@@global.myisam_sort_buffer_size;
+set @my_tx_isolation	  =@@global.tx_isolation;
 
 # case insensitivity tests (new in 5.0)
 set @`test`=1;
@@ -528,8 +529,49 @@
 set global thread_cache_size         =@my_thread_cache_size;
 set global myisam_sort_buffer_size   =@my_myisam_sort_buffer_size;
 
+SHOW GLOBAL VARIABLES LIKE 'max_join_size';
+SHOW LOCAL VARIABLES LIKE 'max_join_size';
+
+set GLOBAL bulk_insert_buffer_size=DEFAULT;
+set GLOBAL join_buffer_size=DEFAULT;
+set GLOBAL max_allowed_packet=DEFAULT;
+set GLOBAL max_connect_errors=DEFAULT;
+set GLOBAL max_heap_table_size=DEFAULT;
+set GLOBAL max_join_size=DEFAULT;
+set GLOBAL max_sort_length=DEFAULT;
+set GLOBAL max_write_lock_count=DEFAULT;
+set GLOBAL myisam_sort_buffer_size=DEFAULT;
+set GLOBAL mysql_protocol_buffer_length=DEFAULT;
+set GLOBAL read_buffer_size=DEFAULT;
+set GLOBAL read_rnd_buffer_size=DEFAULT;
+set GLOBAL server_id=DEFAULT;
+set GLOBAL sort_buffer_size=DEFAULT;
+set GLOBAL table_open_cache=DEFAULT;
+set GLOBAL storage_engine= @my_storage_engine;
+set GLOBAL tmp_table_size=DEFAULT;
+set GLOBAL tx_isolation= @my_tx_isolation;
+
+set SESSION bulk_insert_buffer_size=DEFAULT;
+set SESSION join_buffer_size=DEFAULT;
+set SESSION max_allowed_packet=DEFAULT;
+set SESSION max_heap_table_size=DEFAULT;
+set SESSION max_join_size=DEFAULT;
+set SESSION max_sort_length=DEFAULT;
+set SESSION read_buffer_size=DEFAULT;
+set SESSION read_rnd_buffer_size=DEFAULT;
+set SESSION sort_buffer_size=DEFAULT;
+set SESSION sql_big_selects=DEFAULT;
+set SESSION sql_buffer_result=DEFAULT;
+set SESSION sql_select_limit=DEFAULT;
+set SESSION sql_warnings=DEFAULT;
+set SESSION storage_engine= @my_storage_engine;
+set SESSION tmp_table_size=DEFAULT;
+set SESSION tx_isolation= @my_tx_isolation;
+
 #
 # Bug#28580 Repeatation of status variables
 #
+
 --replace_column 2 #
 show global variables where variable_name='table_definition_cache' or Variable_name='table_lock_wait_timeout';
+

